@@ -1,7 +1,7 @@
 """Application wide configuration."""
 import os
 import tempfile
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
 from typing import Optional
 
 import dataconf
@@ -27,6 +27,8 @@ class Configuration:
 
     org_header: str
 
+    dict = asdict
+
 
 configuration_defaults = {
     "temp_dir": tempfile.gettempdir(),
